@@ -1,5 +1,5 @@
 import redis
-from typing import Union, Any, Tuple, List
+from typing import Union, Any, Tuple, List, Callable
 import pytz
 from c27cache.logger import log_info
 from c27cache.expiry import C27CacheExpiry
@@ -17,6 +17,7 @@ class C27RedisCacheBackend:
         key: str,
         value: str,
         ttl_in_seconds: int = None,
+        ttl_func: Callable=None,
         end_of_day: bool = False,
         end_of_week: bool = False,
     ):
@@ -25,6 +26,7 @@ class C27RedisCacheBackend:
             ttl_in_seconds=ttl_in_seconds,
             end_of_day=end_of_day,
             end_of_week=end_of_week,
+            ttl_func=ttl_func
         )
 
         stringified_value = value
