@@ -1,22 +1,29 @@
 import pytz
+from typing import Callable
 from c27cache.datetime_support import (
     end_of_day,
     tz_now,
     asia_kolkata,
     end_of_week,
 )
+from c27cache.config import C27Cache
 
 
 class C27CacheExpiry:
-    
     @staticmethod
     async def get_ttl(
         ttl_in_seconds: int = None,
         end_of_day: bool = True,
         end_of_week: bool = None,
+        ttl_func: Callable = None,
         tz: pytz.timezone = asia_kolkata,
     ) -> int:
-        """Return the seconds till expiry of cache"""
+        """Return the seconds till expiry of cache. Defaults to one day"""
+        tz = C27Cache.tz or tz
+        
+        if ttl_func:
+            return await ttl_func()
+
         if ttl_in_seconds:
             return ttl_in_seconds
 
@@ -25,12 +32,11 @@ class C27CacheExpiry:
 
         if end_of_week:
             return await C27CacheExpiry.expires_end_of_week(tz=tz)
-    
-        return 
+        return 86400
 
     @staticmethod
     async def expires_end_of_week(tz=asia_kolkata) -> int:
-        """ Returns the seconds till expiry at the end of the week """
+        """Returns the seconds till expiry at the end of the week"""
         now = tz_now()
         local_time = now.astimezone(tz=tz)
         eow = end_of_week(dt=local_time)
@@ -38,7 +44,7 @@ class C27CacheExpiry:
 
     @staticmethod
     async def expires_end_of_day(tz=asia_kolkata) -> int:
-        """ Returns the seconds till expiry at the end of the day """
+        """Returns the seconds till expiry at the end of the day"""
         now = tz_now()
         local_time = now.astimezone(tz=tz)
         eod = end_of_day(dt=local_time)
