@@ -12,6 +12,7 @@ def cache(
     ttl_in_seconds: int = None,
     expire_end_of_day: bool = True,
     expire_end_of_week: bool = False,
+    ttl_func: Callable = None,
     namespace: str = None,
 ):
     """Decorator method that sets the return value to cache before returning.
@@ -22,7 +23,9 @@ def cache(
                              to be accessed to generate the key. Defaults to None.
         obj_attr (str, optional): Name of the attribute for the optional object from the router 
                                   method that needs to be accessed to generate the key. Defaults to None.
-        ttl_in_seconds (int, optional): Time To Live - Duration till which key stays in cache. Defaults to None.
+        ttl_in_seconds (int, optional): Time To Live - Duration till which key stays in cache. Defaults to None.,
+        ttl_func (Callable, optional): Time to Live Callable - Invoked to fetch the number of seconds before 
+                                       the cache key expires
         expire_end_of_day (bool, optional): Helper to set TTL which expires at the end of the day. Defaults to True.
         expire_end_of_week (bool, optional): Helper to set TTL expires at the end of the week. Defaults to False.
         namespace (str, optional): Namespace used for the keys inside redis. 
@@ -64,6 +67,7 @@ def cache(
                     key=_key,
                     value=_cacheable_response,
                     ttl_in_seconds=ttl_in_seconds,
+                    ttl_func=ttl_func,
                     end_of_day=expire_end_of_day,
                     end_of_week=expire_end_of_week,
                 )
